@@ -147,7 +147,7 @@ impl Logger {
                 let mut files = self.files.lock().expect("Someone poisoned logger's mutex");
                 files.logfile = Some(file);
             }
-            Err(error) => eprintln!("Couldn't open `{}' as a logfile: {}", filename, error),
+            Err(error) => eprintln!("Couldn't open `{filename}' as a logfile: {error}"),
         }
     }
 
@@ -170,10 +170,7 @@ impl Logger {
                 let mut files = self.files.lock().expect("Someone poisoned logger's mutex");
                 files.user_error_logfile = Some(file)
             }
-            Err(error) => eprintln!(
-                "Couldn't open `{}' as a user error logfile: {}",
-                filename, error
-            ),
+            Err(error) => eprintln!("Couldn't open `{filename}' as a user error logfile: {error}"),
         }
     }
 
@@ -181,9 +178,7 @@ impl Logger {
     ///
     /// This method is a wrapper around `log_raw()`.
     pub fn log(&self, level: Level, message: &str) {
-        if level == Level::UserError || level as isize <= self.get_loglevel() {
-            self.log_raw(level, message.as_bytes())
-        }
+        self.log_raw(level, message.as_bytes());
     }
 
     /// Writes binary data to the log.
@@ -203,6 +198,10 @@ impl Logger {
     /// If the message couldn't be written for whatever reason, this function ignores the failure.
     /// Were you to check the return value of every log() call, you'd just stop writing logs.
     pub fn log_raw(&self, level: Level, data: &[u8]) {
+        if level != Level::UserError && level as isize > self.get_loglevel() {
+            return;
+        }
+
         let timestamp = Local::now();
         // DateTime::format() is extremely slow; format! is way faster. See
         // https://github.com/chronotope/chrono/issues/94 for details.
@@ -220,7 +219,7 @@ impl Logger {
 
         if level as isize <= self.get_loglevel() {
             if let Some(ref mut logfile) = files.logfile {
-                let level = format!("{}: ", level);
+                let level = format!("{level}: ");
 
                 // Ignoring the error since checking every log() call will be too bothersome.
                 let _ = logfile.write_all(timestamp.as_bytes());
