@@ -103,11 +103,11 @@ impl Operator {
 /// Return 0 if there is no numeric prefix. On underflow, return `std::i32::MIN`. On overflow,
 /// return `std::i32::MAX`.
 fn string_to_num(input: &str) -> i32 {
-    let search_start = if input.starts_with('-') { 1 } else { 0 };
+    let search_start = usize::from(input.starts_with('-'));
 
     let numerics_end = input[search_start..]
         .find(|c: char| !c.is_numeric())
-        .unwrap_or_else(|| input.len())
+        .unwrap_or(input.len())
         + search_start; // Adding the starting offset to get an index inside the original input
 
     if numerics_end - search_start == 0 {
