@@ -266,6 +266,9 @@ ConfigContainer::ConfigContainer()
 	{"miniflux-password", ConfigData("", ConfigDataType::STR)},
 	{"miniflux-passwordfile", ConfigData("", ConfigDataType::PATH)},
 	{"miniflux-passwordeval", ConfigData("", ConfigDataType::STR)},
+	{"miniflux-token", ConfigData("", ConfigDataType::STR)},
+	{"miniflux-tokenfile", ConfigData("", ConfigDataType::PATH)},
+	{"miniflux-tokeneval", ConfigData("", ConfigDataType::STR)},
 	{"miniflux-url", ConfigData("", ConfigDataType::STR)},
 	{
 		"urls-source",
