@@ -108,12 +108,19 @@ int Controller::run(const CliArgsParser& args)
 
 	refresh_on_start = args.refresh_on_start();
 
+	if (args.log_level().has_value()) {
+		logger::set_loglevel(args.log_level().value());
+	}
+
 	if (args.log_file().has_value()) {
 		logger::set_logfile(args.log_file().value());
 	}
 
-	if (args.log_level().has_value()) {
-		logger::set_loglevel(args.log_level().value());
+	if (!args.log_file().has_value() && args.log_level().has_value()) {
+		const std::string date_time_string = utils::mt_strf_localtime("%Y-%m-%d_%H.%M.%S",
+				std::time(nullptr));
+		const std::string filename = "newsboat_" + date_time_string + ".log";
+		logger::set_logfile(filename);
 	}
 
 	if (!args.display_msg().empty()) {
