@@ -154,6 +154,12 @@ void PbView::run(bool auto_download, bool wrap_scroll)
 		case OP_SK_PGDOWN:
 			downloads_list.move_page_down(wrap_scroll);
 			break;
+		case OP_SK_HALF_PAGE_UP:
+			downloads_list.scroll_halfpage_up(wrap_scroll);
+			break;
+		case OP_SK_HALF_PAGE_DOWN:
+			downloads_list.scroll_halfpage_down(wrap_scroll);
+			break;
 		case OP_PB_TOGGLE_DLALL:
 			auto_download = !auto_download;
 			break;
@@ -348,6 +354,12 @@ void PbView::run_help()
 		case OP_SK_PGDOWN:
 			help_textview.scroll_page_down();
 			break;
+		case OP_SK_HALF_PAGE_UP:
+			help_textview.scroll_halfpage_up();
+			break;
+		case OP_SK_HALF_PAGE_DOWN:
+			help_textview.scroll_halfpage_down();
+			break;
 		case OP_HARDQUIT:
 		case OP_QUIT:
 			quit = true;
