@@ -5,9 +5,10 @@
 #include <unistd.h>
 
 #include "3rd-party/catch.hpp"
-#include "test-helpers/chmod.h"
-#include "test-helpers/misc.h"
-#include "test-helpers/tempfile.h"
+#include "test_helpers/chmod.h"
+#include "test_helpers/misc.h"
+#include "test_helpers/tempfile.h"
+#include "utils.h"
 
 using namespace newsboat;
 
@@ -63,9 +64,9 @@ TEST_CASE("URL reader writes files that it can understand later",
 	"[FileUrlReader]")
 {
 	const std::string testDataPath("data/test-urls.txt");
-	TestHelpers::TempFile urlsFile;
+	test_helpers::TempFile urlsFile;
 
-	TestHelpers::copy_file(testDataPath, urlsFile.get_path());
+	test_helpers::copy_file(testDataPath, urlsFile.get_path());
 
 	FileUrlReader u(urlsFile.get_path());
 	u.reload();
@@ -102,21 +103,20 @@ TEST_CASE("Preserves URLs as-is", "[FileUrlReader][issue926]")
 		R"_(exec:curl --silent https://feeds.metaebene.me/raumzeit/m4a  | sed 's#\(</guid>\|</id>\)#-M4A&#')_");
 }
 
-TEST_CASE("URL reader returns error message if file cannot be opened",
+TEST_CASE("URL reader returns error structure if file cannot be opened",
 	"[FileUrlReader]")
 {
 	const std::string testDataPath("data/test-urls.txt");
 
-	TestHelpers::TempFile urlsFile;
+	test_helpers::TempFile urlsFile;
 	FileUrlReader u(urlsFile.get_path());
 
-	SECTION("reload() returns error message if file does not exist") {
+	SECTION("reload() returns error structure if file does not exist") {
 		const auto error_message = u.reload();
 		REQUIRE(error_message.has_value());
-
-		SECTION("the error message contains the filename") {
-			INFO("error_message: " + error_message.value());
-			REQUIRE(error_message.value().find(urlsFile.get_path()) != std::string::npos);
+		SECTION("the error structure contains error message and kind of an error") {
+			INFO("error_message: " + error_message.value().message);
+			REQUIRE_FALSE(error_message.value().message.empty());
 		}
 	}
 
@@ -130,7 +130,7 @@ TEST_CASE("URL reader returns error message if file cannot be opened",
 		}
 	}
 
-	TestHelpers::copy_file(testDataPath, urlsFile.get_path());
+	test_helpers::copy_file(testDataPath, urlsFile.get_path());
 
 	SECTION("reload() succeeds if url file exists") {
 		const auto error_message = u.reload();
@@ -138,16 +138,11 @@ TEST_CASE("URL reader returns error message if file cannot be opened",
 	}
 
 	GIVEN("that the urls file is not readable") {
-		TestHelpers::Chmod notReadable(urlsFile.get_path(), S_IWUSR);
+		test_helpers::Chmod notReadable(urlsFile.get_path(), S_IWUSR);
 
 		THEN("reload() returns an error message") {
 			const auto error_message = u.reload();
 			REQUIRE(error_message.has_value());
-
-			SECTION("the error message contains the filename") {
-				INFO("error_message: " + error_message.value());
-				REQUIRE(error_message.value().find(urlsFile.get_path()) != std::string::npos);
-			}
 		}
 
 		THEN("write_config() still works fine") {
@@ -157,7 +152,7 @@ TEST_CASE("URL reader returns error message if file cannot be opened",
 	}
 
 	GIVEN("that the urls file is not writable") {
-		TestHelpers::Chmod notWritable(urlsFile.get_path(), S_IRUSR);
+		test_helpers::Chmod notWritable(urlsFile.get_path(), S_IRUSR);
 
 		THEN("write_config() returns an error message") {
 			const auto error_message = u.write_config();
@@ -179,7 +174,7 @@ TEST_CASE("URL reader returns error message if file cannot be opened",
 TEST_CASE("URL reader returns error message if file contains invalid UTF-8 codepoint",
 	"[FileUrlReader]")
 {
-	TestHelpers::TempFile urlsFile;
+	test_helpers::TempFile urlsFile;
 
 	{
 		std::ofstream f(urlsFile.get_path());
@@ -190,7 +185,7 @@ TEST_CASE("URL reader returns error message if file contains invalid UTF-8 codep
 	FileUrlReader u(urlsFile.get_path());
 	auto error_message = u.reload();
 	REQUIRE(error_message.has_value());
-	REQUIRE(error_message.value().size() > 0);
+	REQUIRE(error_message.value().message.size() > 0);
 }
 
 TEST_CASE("FileUrlReader::get_alltags() returns all unique tags across all feeds, "
